@@ -215,7 +215,7 @@ qint64 Utility::freeDiskSpace(const QString &path)
 #elif defined(Q_OS_WIN)
     ULARGE_INTEGER freeBytes;
     freeBytes.QuadPart = 0L;
-    if (GetDiskFreeSpaceEx(reinterpret_cast<const wchar_t *>(path.utf16()), &freeBytes, NULL, NULL)) {
+    if (GetDiskFreeSpaceEx(reinterpret_cast<const wchar_t *>(path.utf16()), &freeBytes, nullptr, nullptr)) {
         return freeBytes.QuadPart;
     }
 #endif
@@ -255,7 +255,7 @@ void Utility::usleep(int usec)
 }
 
 // This can be overriden from the tests
-OCSYNC_EXPORT bool fsCasePreserving_override = []()-> bool {
+OCSYNC_EXPORT bool fsCasePreserving_override = []() -> bool {
     QByteArray env = qgetenv("OWNCLOUD_TEST_CASE_PRESERVING");
     if (!env.isEmpty())
         return env.toInt();
@@ -298,7 +298,7 @@ namespace {
 
         QString description(quint64 value) const
         {
-            return QCoreApplication::translate("Utility", name, 0, value);
+            return QCoreApplication::translate("Utility", name, nullptr, value);
         }
     };
 // QTBUG-3945 and issue #4855: QT_TRANSLATE_NOOP does not work with plural form because lupdate
@@ -313,7 +313,7 @@ namespace {
         { QT_TRANSLATE_NOOP("Utility", "%n hour(s)", 0, _), 3600 * 1000LL },
         { QT_TRANSLATE_NOOP("Utility", "%n minute(s)", 0, _), 60 * 1000LL },
         { QT_TRANSLATE_NOOP("Utility", "%n second(s)", 0, _), 1000LL },
-        { 0, 0 }
+        { nullptr, 0 }
     };
 } // anonymous namespace
 
@@ -362,12 +362,12 @@ QString Utility::fileNameForGuiUse(const QString &fName)
 QByteArray Utility::normalizeEtag(QByteArray etag)
 {
     /* strip "XXXX-gzip" */
-    if(etag.startsWith('"') && etag.endsWith("-gzip\"")) {
+    if (etag.startsWith('"') && etag.endsWith("-gzip\"")) {
         etag.chop(6);
         etag.remove(0, 1);
     }
     /* strip trailing -gzip */
-    if(etag.endsWith("-gzip")) {
+    if (etag.endsWith("-gzip")) {
         etag.chop(5);
     }
     /* strip normal quotes */
@@ -392,7 +392,7 @@ QString Utility::platformName()
 
 void Utility::crash()
 {
-    volatile int *a = (int *)(NULL);
+    volatile int *a = (int *)nullptr;
     *a = 1;
 }
 
@@ -400,7 +400,7 @@ void Utility::crash()
 // without compiler warnings about possible truncation
 uint Utility::convertSizeToUint(size_t &convertVar)
 {
-    if( convertVar > UINT_MAX ) {
+    if (convertVar > UINT_MAX) {
         //throw std::bad_cast();
         convertVar = UINT_MAX; // intentionally default to wrong value here to not crash: exception handling TBD
     }
@@ -409,7 +409,7 @@ uint Utility::convertSizeToUint(size_t &convertVar)
 
 uint Utility::convertSizeToInt(size_t &convertVar)
 {
-    if( convertVar > INT_MAX ) {
+    if (convertVar > INT_MAX) {
         //throw std::bad_cast();
         convertVar = INT_MAX; // intentionally default to wrong value here to not crash: exception handling TBD
     }
@@ -465,7 +465,7 @@ QString Utility::timeAgoInWords(const QDateTime &dt, const QDateTime &from)
 
         if (floor(secs / 3600.0) > 0) {
             int hours = floor(secs / 3600.0);
-            if(hours == 1){
+            if (hours == 1) {
                 return (QObject::tr("%n hour ago", "", hours));
             } else {
                 return (QObject::tr("%n hours ago", "", hours));
@@ -480,7 +480,7 @@ QString Utility::timeAgoInWords(const QDateTime &dt, const QDateTime &from)
                     return QObject::tr("Less than a minute ago");
                 }
 
-            } else if(minutes == 1){
+            } else if (minutes == 1) {
                 return (QObject::tr("%n minute ago", "", minutes));
             } else {
                 return (QObject::tr("%n minutes ago", "", minutes));
