@@ -57,7 +57,7 @@ static void setupFavLink_private(const QString &folder)
     /* Use new WINAPI functions */
     PWSTR path;
 
-    if (SHGetKnownFolderPath(FOLDERID_Links, 0, NULL, &path) == S_OK) {
+    if (SHGetKnownFolderPath(FOLDERID_Links, 0, nullptr, &path) == S_OK) {
         QString links = QDir::fromNativeSeparators(QString::fromWCharArray(path));
         linkName = QDir(links).filePath(folderDir.dirName() + QLatin1String(".lnk"));
         CoTaskMemFree(path);
@@ -100,6 +100,20 @@ static inline bool hasDarkSystray_private()
     }
 }
 
+QRect Utility::getTaskbarDimensions()
+{
+    APPBARDATA barData;
+    barData.cbSize = sizeof(APPBARDATA);
+
+    BOOL fResult = (BOOL)SHAppBarMessage(ABM_GETTASKBARPOS, &barData);
+    if (!fResult) {
+        return QRect();
+    }
+
+    RECT barRect = barData.rc;
+    return QRect(barRect.left, barRect.top, (barRect.right - barRect.left), (barRect.bottom - barRect.top));
+}
+
 QVariant Utility::registryGetKeyValue(HKEY hRootKey, const QString &subKey, const QString &valueName)
 {
     QVariant value;
@@ -142,6 +156,15 @@ QVariant Utility::registryGetKeyValue(HKEY hRootKey, const QString &subKey, cons
             }
             break;
         }
+        case REG_BINARY: {
+            QByteArray buffer;
+            buffer.resize(sizeInBytes);
+            result = RegQueryValueEx(hKey, reinterpret_cast<LPCWSTR>(valueName.utf16()), 0, &type, reinterpret_cast<LPBYTE>(buffer.data()), &sizeInBytes);
+            if (result == ERROR_SUCCESS) {
+                value = buffer.at(12);
+            }
+            break;
+        }
         default:
             Q_UNREACHABLE();
         }
