@@ -37,7 +37,7 @@ Q_LOGGING_CATEGORY(lcReconcile, "nextcloud.sync.csync.reconciler", QtInfoMsg)
 #include "inttypes.h"
 
 /* Check if a file is ignored because one parent is ignored.
- * return the node of the ignored directoy if it's the case, or NULL if it is not ignored */
+ * return the node of the ignored directoy if it's the case, or \c nullptr if it is not ignored */
 static csync_file_stat_t *_csync_check_ignored(csync_s::FileMap *tree, const ByteArrayRef &path)
 {
     /* compute the size of the parent directory */
@@ -178,9 +178,22 @@ static void _csync_merge_algorithm_visitor(csync_file_stat_t *cur, CSYNC * ctx)
                         basePath.constData(), other ? "found" : "not found");
                 }
 
+                const auto curParentPath = [=]{
+                    const auto slashPosition = cur->path.lastIndexOf('/');
+                    if (slashPosition >= 0) {
+                        return cur->path.left(slashPosition);
+                    } else {
+                        return QByteArray();
+                    }
+                }();
+                auto curParent = our_tree->findFile(curParentPath);
+
                 if(!other) {
                     // Stick with the NEW
                     return;
+                } else if (!other->e2eMangledName.isEmpty() || (curParent && curParent->isE2eEncrypted)) {
+                    // Stick with the NEW as well, we want to always issue delete + upload in such cases
+                    return;
                 } else if (other->instruction == CSYNC_INSTRUCTION_RENAME) {
                     // Some other EVAL_RENAME already claimed other.
                     // We do nothing: maybe a different candidate for
