@@ -63,8 +63,8 @@ static bool _csync_sameextension(const char *p1, const char *p2) {
 
     /* If the found extension contains a '/', it is because the . was in the folder name
      *            => no extensions */
-    if (e1 && strchr(e1, '/')) e1 = NULL;
-    if (e2 && strchr(e2, '/')) e2 = NULL;
+    if (e1 && strchr(e1, '/')) e1 = nullptr;
+    if (e2 && strchr(e2, '/')) e2 = nullptr;
 
     /* If none have extension, it is the same extension */
     if (!e1 && !e2)
@@ -203,7 +203,8 @@ static int _csync_detect_update(CSYNC *ctx, std::unique_ptr<csync_file_stat_t> f
 
   if(base.isValid()) { /* there is an entry in the database */
       // When the file is loaded from the file system it misses
-      // the e2e mangled name
+      // the e2e mangled name and e2e encryption status
+      fs->isE2eEncrypted = base._isE2eEncrypted;
       if (fs->e2eMangledName.isEmpty() && !base._e2eMangledName.isEmpty()) {
           fs->e2eMangledName = base._e2eMangledName;
           fs->path = base._path;
@@ -590,9 +591,9 @@ int csync_ftw(CSYNC *ctx, const char *uri, csync_walker_fn fn,
     unsigned int depth) {
   QByteArray filename;
   QByteArray fullpath;
-  csync_vio_handle_t *dh = NULL;
+  csync_vio_handle_t *dh = nullptr;
   std::unique_ptr<csync_file_stat_t> dirent;
-  csync_file_stat_t *previous_fs = NULL;
+  csync_file_stat_t *previous_fs = nullptr;
   int read_from_db = 0;
   int rc = 0;
 
@@ -617,7 +618,7 @@ int csync_ftw(CSYNC *ctx, const char *uri, csync_walker_fn fn,
   // if the etag of this dir is still the same, its content is restored from the
   // database.
   if( do_read_from_db ) {
-      if( ! fill_tree_from_db(ctx, db_uri) ) {
+      if(!fill_tree_from_db(ctx, db_uri)) {
         errno = ENOENT;
         ctx->status_code = CSYNC_STATUS_OPENDIR_ERROR;
         goto error;
@@ -625,7 +626,7 @@ int csync_ftw(CSYNC *ctx, const char *uri, csync_walker_fn fn,
       return 0;
   }
 
-  if ((dh = csync_vio_opendir(ctx, uri)) == NULL) {
+  if (!(dh = csync_vio_opendir(ctx, uri))) {
       if (ctx->abort) {
           qCDebug(lcUpdate, "Aborted!");
           ctx->status_code = CSYNC_STATUS_ABORTED;
@@ -783,7 +784,7 @@ int csync_ftw(CSYNC *ctx, const char *uri, csync_walker_fn fn,
 
 error:
   ctx->remote.read_from_db = read_from_db;
-  if (dh != NULL) {
+  if (dh) {
     csync_vio_closedir(ctx, dh);
   }
   return -1;
