@@ -20,6 +20,7 @@
 #include "creds/httpcredentials.h"
 #include "logger.h"
 #include "configfile.h"
+#include "ocsnavigationappsjob.h"
 
 #include <QSettings>
 #include <QTimer>
@@ -27,6 +28,7 @@
 
 #include <QJsonDocument>
 #include <QJsonObject>
+#include <QJsonArray>
 #include <QNetworkRequest>
 #include <QBuffer>
 
@@ -40,7 +42,6 @@ AccountState::AccountState(AccountPtr account)
     , _state(AccountState::Disconnected)
     , _connectionStatus(ConnectionValidator::Undefined)
     , _waitingForNewCredentials(false)
-    , _notificationsEtagResponseHeader("*")
     , _maintenanceToConnectedDelay(60000 + (qrand() % (4 * 60000))) // 1-5min delay
     , _remoteWipe(new RemoteWipe(_account))
 {
@@ -55,9 +56,7 @@ AccountState::AccountState(AccountPtr account)
     _timeSinceLastETagCheck.invalidate();
 }
 
-AccountState::~AccountState()
-{
-}
+AccountState::~AccountState() = default;
 
 AccountState *AccountState::loadFromSettings(AccountPtr account, QSettings & /*settings*/)
 {
@@ -229,7 +228,7 @@ void AccountState::checkConnectivity()
         return;
     }
 
-    ConnectionValidator *conValidator = new ConnectionValidator(account());
+    auto *conValidator = new ConnectionValidator(AccountStatePtr(this));
     _connectionValidator = conValidator;
     connect(conValidator, &ConnectionValidator::connectionResult,
         this, &AccountState::slotConnectionValidatorResult);
@@ -237,6 +236,9 @@ void AccountState::checkConnectivity()
         // Use a small authed propfind as a minimal ping when we're
         // already connected.
         conValidator->checkAuthentication();
+
+        // Get the Apps available on the server.
+        fetchNavigationApps();
     } else {
         // Check the server and then the auth.
 
@@ -267,7 +269,7 @@ void AccountState::slotConnectionValidatorResult(ConnectionValidator::Status sta
     // Come online gradually from 503 or maintenance mode
     if (status == ConnectionValidator::Connected
         && (_connectionStatus == ConnectionValidator::ServiceUnavailable
-               || _connectionStatus == ConnectionValidator::MaintenanceMode)) {
+            || _connectionStatus == ConnectionValidator::MaintenanceMode)) {
         if (!_timeSinceMaintenanceOver.isValid()) {
             qCInfo(lcAccountState) << "AccountState reconnection: delaying for"
                                    << _maintenanceToConnectedDelay << "ms";
@@ -293,6 +295,9 @@ void AccountState::slotConnectionValidatorResult(ConnectionValidator::Status sta
     case ConnectionValidator::Connected:
         if (_state != Connected) {
             setState(Connected);
+
+            // Get the Apps available on the server.
+            fetchNavigationApps();
         }
         break;
     case ConnectionValidator::Undefined:
@@ -405,4 +410,106 @@ std::unique_ptr<QSettings> AccountState::settings()
     return s;
 }
 
+void AccountState::fetchNavigationApps(){
+    auto *job = new OcsNavigationAppsJob(_account);
+    job->addRawHeader("If-None-Match", navigationAppsEtagResponseHeader());
+    connect(job, &OcsNavigationAppsJob::appsJobFinished, this, &AccountState::slotNavigationAppsFetched);
+    connect(job, &OcsNavigationAppsJob::etagResponseHeaderReceived, this, &AccountState::slotEtagResponseHeaderReceived);
+    connect(job, &OcsNavigationAppsJob::ocsError, this, &AccountState::slotOcsError);
+    job->getNavigationApps();
+}
+
+void AccountState::slotEtagResponseHeaderReceived(const QByteArray &value, int statusCode){
+    if(statusCode == 200){
+        qCDebug(lcAccountState) << "New navigation apps ETag Response Header received " << value;
+        setNavigationAppsEtagResponseHeader(value);
+    }
+}
+
+void AccountState::slotOcsError(int statusCode, const QString &message)
+{
+    qCDebug(lcAccountState) << "Error " << statusCode << " while fetching new navigation apps: " << message;
+}
+
+void AccountState::slotNavigationAppsFetched(const QJsonDocument &reply, int statusCode)
+{
+    if(_account){
+        if (statusCode == 304) {
+            qCWarning(lcAccountState) << "Status code " << statusCode << " Not Modified - No new navigation apps.";
+        } else {
+            _apps.clear();
+
+            if(!reply.isEmpty()){
+                auto element = reply.object().value("ocs").toObject().value("data");
+                auto navLinks = element.toArray();
+
+                if(navLinks.size() > 0){
+                    foreach (const QJsonValue &value, navLinks) {
+                        auto navLink = value.toObject();
+
+                        auto *app = new AccountApp(navLink.value("name").toString(), QUrl(navLink.value("href").toString()),
+                            navLink.value("id").toString(), QUrl(navLink.value("icon").toString()));
+
+                        _apps << app;
+                    }
+                }
+            }
+
+            emit hasFetchedNavigationApps();
+        }
+    }
+}
+
+AccountAppList AccountState::appList() const
+{
+    return _apps;
+}
+
+AccountApp* AccountState::findApp(const QString &appId) const
+{
+    if(!appId.isEmpty()) {
+        foreach(AccountApp *app, appList()) {
+            if(app->id() == appId)
+                return app;
+        }
+    }
+
+    return nullptr;
+}
+
+/*-------------------------------------------------------------------------------------*/
+
+AccountApp::AccountApp(const QString &name, const QUrl &url,
+    const QString &id, const QUrl &iconUrl,
+    QObject *parent)
+    : QObject(parent)
+    , _name(name)
+    , _url(url)
+    , _id(id)
+    , _iconUrl(iconUrl)
+{
+}
+
+QString AccountApp::name() const
+{
+    return _name;
+}
+
+QUrl AccountApp::url() const
+{
+    return _url;
+}
+
+QString AccountApp::id() const
+{
+    return _id;
+}
+
+QUrl AccountApp::iconUrl() const
+{
+    return _iconUrl;
+}
+
+/*-------------------------------------------------------------------------------------*/
+
 } // namespace OCC
