@@ -82,7 +82,7 @@ Folder::Folder(const FolderDefinition &definition,
         qCWarning(lcFolder, "Could not read system exclude file");
 
     connect(_accountState.data(), &AccountState::isConnectedChanged, this, &Folder::canSyncChanged);
-    connect(_engine.data(), &SyncEngine::rootEtag, this, &Folder::etagRetreivedFromSyncEngine);
+    connect(_engine.data(), &SyncEngine::rootEtag, this, &Folder::etagRetrievedFromSyncEngine);
 
     connect(_engine.data(), &SyncEngine::started, this, &Folder::slotSyncStarted, Qt::QueuedConnection);
     connect(_engine.data(), &SyncEngine::finished, this, &Folder::slotSyncFinished, Qt::QueuedConnection);
@@ -293,12 +293,12 @@ void Folder::slotRunEtagJob()
     _requestEtagJob = new RequestEtagJob(account, remotePath(), this);
     _requestEtagJob->setTimeout(60 * 1000);
     // check if the etag is different when retrieved
-    QObject::connect(_requestEtagJob.data(), &RequestEtagJob::etagRetreived, this, &Folder::etagRetreived);
+    QObject::connect(_requestEtagJob.data(), &RequestEtagJob::etagRetrieved, this, &Folder::etagRetrieved);
     FolderMan::instance()->slotScheduleETagJob(alias(), _requestEtagJob);
     // The _requestEtagJob is auto deleting itself on finish. Our guard pointer _requestEtagJob will then be null.
 }
 
-void Folder::etagRetreived(const QString &etag)
+void Folder::etagRetrieved(const QString &etag)
 {
     // re-enable sync if it was disabled because network was down
     FolderMan::instance()->setSyncEnabled(true);
@@ -312,7 +312,7 @@ void Folder::etagRetreived(const QString &etag)
     _accountState->tagLastSuccessfullETagRequest();
 }
 
-void Folder::etagRetreivedFromSyncEngine(const QString &etag)
+void Folder::etagRetrievedFromSyncEngine(const QString &etag)
 {
     qCInfo(lcFolder) << "Root etag from during sync:" << etag;
     accountState()->tagLastSuccessfullETagRequest();
@@ -903,18 +903,20 @@ void Folder::slotItemCompleted(const SyncFileItemPtr &item)
 
     // add new directories or remove gone away dirs to the watcher
     if (_folderWatcher && item->isDirectory()) {
-	switch (item->_instruction) {
-	    case CSYNC_INSTRUCTION_NEW:
+    switch (item->_instruction) {
+        case CSYNC_INSTRUCTION_NEW:
                 _folderWatcher->addPath(path() + item->_file);
-	    break;
-	    case CSYNC_INSTRUCTION_REMOVE:
+        break;
+        case CSYNC_INSTRUCTION_REMOVE:
                 _folderWatcher->removePath(path() + item->_file);
-	    break;
-	    case CSYNC_INSTRUCTION_RENAME:
+        break;
+        case CSYNC_INSTRUCTION_RENAME:
                 _folderWatcher->removePath(path() + item->_file);
                 _folderWatcher->addPath(path() + item->destination());
-	    break;
-	}
+        break;
+        default:
+        break;
+    }
     }
 
     // Success and failure of sync items adjust what the next sync is
@@ -951,7 +953,8 @@ void Folder::slotNewBigFolderDiscovered(const QString &newF, bool isExternal)
     auto journal = journalDb();
 
     // Add the entry to the blacklist if it is neither in the blacklist or whitelist already
-    bool ok1, ok2;
+    bool ok1 = false;
+    bool ok2 = false;
     auto blacklist = journal->getSelectiveSyncList(SyncJournalDb::SelectiveSyncBlackList, &ok1);
     auto whitelist = journal->getSelectiveSyncList(SyncJournalDb::SelectiveSyncWhiteList, &ok2);
     if (ok1 && ok2 && !blacklist.contains(newFolder) && !whitelist.contains(newFolder)) {
@@ -1204,7 +1207,7 @@ QString FolderDefinition::absoluteJournalPath() const
 
 QString FolderDefinition::defaultJournalPath(AccountPtr account)
 {
-    return SyncJournalDb::makeDbName(localPath, account->url(), targetPath, account->credentials()->user());
+    return SyncJournalDb::makeDbName(account->url(), targetPath, account->credentials()->user());
 }
 
 } // namespace OCC
