@@ -47,26 +47,18 @@ class FolderWatcher;
 class FolderDefinition
 {
 public:
-    FolderDefinition()
-        : paused(false)
-        , ignoreHiddenFiles(false)
-    {
-    }
-
     /// The name of the folder in the ui and internally
     QString alias;
     /// path on local machine
     QString localPath;
-    /// path to the journal, usually relative to localPath
+    /// path to the journal, usually in QStandardPaths::AppDataLocation
     QString journalPath;
     /// path on remote
     QString targetPath;
     /// whether the folder is paused
-    bool paused;
+    bool paused = false;
     /// whether the folder syncs hidden files
-    bool ignoreHiddenFiles;
-    /// the folder has client side encryption
-    bool isClientSideEncrypted;
+    bool ignoreHiddenFiles = false;
     /// The CLSID where this folder appears in registry for the Explorer navigation pane entry.
     QUuid navigationPaneClsid;
 
@@ -298,8 +290,8 @@ private slots:
     void slotItemCompleted(const SyncFileItemPtr &);
 
     void slotRunEtagJob();
-    void etagRetreived(const QString &);
-    void etagRetreivedFromSyncEngine(const QString &);
+    void etagRetrieved(const QString &);
+    void etagRetrievedFromSyncEngine(const QString &);
 
     void slotEmitFinishedDelayed();
 
