@@ -23,8 +23,11 @@
 #include "accountmanager.h"
 #include "synclogdialog.h"
 
+#if defined(BUILD_UPDATER)
 #include "updater/updater.h"
 #include "updater/ocupdater.h"
+#endif
+
 #include "ignorelisteditor.h"
 #include "common/utility.h"
 
@@ -47,7 +50,6 @@ namespace OCC {
 GeneralSettings::GeneralSettings(QWidget *parent)
     : QWidget(parent)
     , _ui(new Ui::GeneralSettings)
-    , _currentlyLoading(false)
 {
     _ui->setupUi(this);
 
@@ -100,12 +102,18 @@ GeneralSettings::GeneralSettings(QWidget *parent)
         if (QOperatingSystemVersion::current() < QOperatingSystemVersion::Windows10)
     #endif
             _ui->showInExplorerNavigationPaneCheckBox->setVisible(false);
+#else
+    // Hide on non-Windows
+    _ui->showInExplorerNavigationPaneCheckBox->setVisible(false);
 #endif
 
     /* Set the left contents margin of the layout to zero to make the checkboxes
      * align properly vertically , fixes bug #3758
      */
-    int m0, m1, m2, m3;
+    int m0 = 0;
+    int m1 = 0;
+    int m2 = 0;
+    int m3 = 0;
     _ui->horizontalLayout_3->getContentsMargins(&m0, &m1, &m2, &m3);
     _ui->horizontalLayout_3->setContentsMargins(0, m1, m2, m3);
 
@@ -129,7 +137,10 @@ GeneralSettings::~GeneralSettings()
 
 QSize GeneralSettings::sizeHint() const
 {
-    return QSize(ownCloudGui::settingsDialogSize().width(), QWidget::sizeHint().height());
+    return {
+        ownCloudGui::settingsDialogSize().width(),
+        QWidget::sizeHint().height()
+    };
 }
 
 void GeneralSettings::loadMiscSettings()
@@ -147,10 +158,11 @@ void GeneralSettings::loadMiscSettings()
     _ui->monoIconsCheckBox->setChecked(cfgFile.monoIcons());
 }
 
+#if defined(BUILD_UPDATER)
 void GeneralSettings::slotUpdateInfo()
 {
     // Note: the sparkle-updater is not an OCUpdater
-    OCUpdater *updater = qobject_cast<OCUpdater *>(Updater::instance());
+    auto *updater = qobject_cast<OCUpdater *>(Updater::instance());
     if (ConfigFile().skipUpdateCheck()) {
         updater = nullptr; // don't show update info if updates are disabled
     }
@@ -159,18 +171,48 @@ void GeneralSettings::slotUpdateInfo()
         connect(updater, &OCUpdater::downloadStateChanged, this, &GeneralSettings::slotUpdateInfo, Qt::UniqueConnection);
         connect(_ui->restartButton, &QAbstractButton::clicked, updater, &OCUpdater::slotStartInstaller, Qt::UniqueConnection);
         connect(_ui->restartButton, &QAbstractButton::clicked, qApp, &QApplication::quit, Qt::UniqueConnection);
+        connect(_ui->updateButton, &QAbstractButton::clicked, this, &GeneralSettings::slotUpdateCheckNow, Qt::UniqueConnection);
+        connect(_ui->autoCheckForUpdatesCheckBox, &QAbstractButton::toggled, this, &GeneralSettings::slotToggleAutoUpdateCheck);
 
         QString status = updater->statusString();
         Theme::replaceLinkColorStringBackgroundAware(status);
         _ui->updateStateLabel->setText(status);
 
         _ui->restartButton->setVisible(updater->downloadState() == OCUpdater::DownloadComplete);
+
+        _ui->updateButton->setEnabled(updater->downloadState() != OCUpdater::CheckingServer &&
+                                      updater->downloadState() != OCUpdater::Downloading &&
+                                      updater->downloadState() != OCUpdater::DownloadComplete);
+
+        _ui->autoCheckForUpdatesCheckBox->setChecked(ConfigFile().autoUpdateCheck());
     } else {
         // can't have those infos from sparkle currently
         _ui->updatesGroupBox->setVisible(false);
     }
 }
 
+void GeneralSettings::slotUpdateCheckNow()
+{
+    auto *updater = qobject_cast<OCUpdater *>(Updater::instance());
+    if (ConfigFile().skipUpdateCheck()) {
+        updater = nullptr; // don't show update info if updates are disabled
+    }
+
+    if (updater) {
+        _ui->updateButton->setEnabled(false);
+
+        updater->checkForUpdate();
+    }
+}
+
+void GeneralSettings::slotToggleAutoUpdateCheck()
+{
+    ConfigFile cfgFile;
+    bool isChecked = _ui->autoCheckForUpdatesCheckBox->isChecked();
+    cfgFile.setAutoUpdateCheck(isChecked, QString());
+}
+#endif // defined(BUILD_UPDATER)
+
 void GeneralSettings::saveMiscSettings()
 {
     if (_currentlyLoading)
@@ -237,8 +279,12 @@ void GeneralSettings::customizeStyle()
     Theme::replaceLinkColorStringBackgroundAware(about);
     _ui->aboutLabel->setText(about);
 
+#if defined(BUILD_UPDATER)
     // updater info
     slotUpdateInfo();
+#else
+    _ui->updatesGroupBox->setVisible(false);
+#endif
 }
 
 } // namespace OCC
