@@ -47,10 +47,14 @@ private slots:
     void slotToggleLaunchOnStartup(bool);
     void slotToggleOptionalServerNotifications(bool);
     void slotShowInExplorerNavigationPane(bool);
-    void slotUpdateInfo();
     void slotIgnoreFilesEditor();
     void loadMiscSettings();
     void slotShowLegalNotice();
+#if defined(BUILD_UPDATER)
+    void slotUpdateInfo();
+    void slotUpdateCheckNow();
+    void slotToggleAutoUpdateCheck();
+#endif
 
 private:
     void customizeStyle();
@@ -58,7 +62,7 @@ private:
     Ui::GeneralSettings *_ui;
     QPointer<IgnoreListEditor> _ignoreEditor;
     QPointer<SyncLogDialog> _syncLogDialog;
-    bool _currentlyLoading;
+    bool _currentlyLoading = false;
 };
 
 
