@@ -26,11 +26,14 @@
 #include "common/utility.h"
 #include "cocoainitializer.h"
 
+#if defined(BUILD_UPDATER)
 #include "updater/updater.h"
+#endif
 
 #include <QTimer>
 #include <QMessageBox>
 #include <QDebug>
+#include <QQuickStyle>
 
 using namespace OCC;
 
@@ -46,7 +49,14 @@ void warnSystray()
 
 int main(int argc, char **argv)
 {
-    Q_INIT_RESOURCE(client);
+    Q_INIT_RESOURCE(resources);
+
+    // Work around a bug in KDE's qqc2-desktop-style which breaks
+    // buttons with icons not based on a name, by forcing a style name
+    // the platformtheme plugin won't try to force qqc2-desktops-style
+    // anymore.
+    // Can be removed once the bug in qqc2-desktop-style is gone.
+    QQuickStyle::setStyle("Default");
 
     // OpenSSL 1.1.0: No explicit initialisation or de-initialisation is necessary.
 
@@ -103,6 +113,8 @@ int main(int argc, char **argv)
         }
     }
 #endif
+
+#if defined(BUILD_UPDATER)
     // if handleStartup returns true, main()
     // needs to terminate here, e.g. because
     // the updater is triggered
@@ -110,6 +122,7 @@ int main(int argc, char **argv)
     if (updater && updater->handleStartup()) {
         return 1;
     }
+#endif
 
     // if the application is already running, notify it.
     if (app.isRunning()) {
@@ -126,7 +139,7 @@ int main(int argc, char **argv)
             if (!app.sendMessage(QLatin1String("MSG_PARSEOPTIONS:") + msg))
                 return -1;
         }
-        if (!app.backgroundMode() && !app.sendMessage(QLatin1String("MSG_SHOWSETTINGS"))) {
+        if (!app.backgroundMode() && !app.sendMessage(QLatin1String("MSG_SHOWMAINDIALOG"))) {
             return -1;
         }
         return 0;
@@ -159,7 +172,7 @@ int main(int argc, char **argv)
                 }
             }
             if (!app.backgroundMode() && !QSystemTrayIcon::isSystemTrayAvailable() && desktopSession != "ubuntu") {
-                app.showSettingsDialog();
+                app.showMainDialog();
             }
         }
     }
