@@ -73,6 +73,17 @@ void OcsShareJob::setPassword(const QString &shareId, const QString &password)
     start();
 }
 
+void OcsShareJob::setNote(const QString &shareId, const QString &note)
+{
+    appendPath(shareId);
+    setVerb("PUT");
+
+    addParam(QString::fromLatin1("note"), note);
+    _value = note;
+
+    start();
+}
+
 void OcsShareJob::setPublicUpload(const QString &shareId, bool publicUpload)
 {
     appendPath(shareId);
@@ -138,9 +149,6 @@ void OcsShareJob::createShare(const QString &path,
     addParam(QString::fromLatin1("path"), path);
     addParam(QString::fromLatin1("shareType"), QString::number(shareType));
     addParam(QString::fromLatin1("shareWith"), shareWith);
-    if (!(permissions & SharePermissionDefault)) {
-        addParam(QString::fromLatin1("permissions"), QString::number(permissions));
-    }
 
     start();
 }
