@@ -40,6 +40,8 @@ QString Sharee::format() const
         formatted += QLatin1String(" (group)");
     } else if (_type == Type::Federated) {
         formatted += QLatin1String(" (remote)");
+    } else if (_type == Type::Circle) {
+        formatted += QLatin1String(" (circle)");
     }
 
     return formatted;
@@ -71,7 +73,7 @@ void ShareeModel::fetch(const QString &search, const ShareeSet &blacklist)
 {
     _search = search;
     _shareeBlacklist = blacklist;
-    OcsShareeJob *job = new OcsShareeJob(_account);
+    auto *job = new OcsShareeJob(_account);
     connect(job, &OcsShareeJob::shareeJobFinished, this, &ShareeModel::shareesFetched);
     connect(job, &OcsJob::ocsError, this, &ShareeModel::displayErrorMessage);
     job->getSharees(_search, _type, 1, 50);
@@ -92,14 +94,21 @@ void ShareeModel::shareesFetched(const QJsonDocument &reply)
         foreach (auto user, users) {
             newSharees.append(parseSharee(user.toObject()));
         }
+
         auto groups = exact.value("groups").toArray();
         foreach (auto group, groups) {
             newSharees.append(parseSharee(group.toObject()));
         }
+
         auto remotes = exact.value("remotes").toArray();
         foreach (auto remote, remotes) {
             newSharees.append(parseSharee(remote.toObject()));
         }
+
+        auto circles = exact.value("circles").toArray();
+        foreach (auto circle, circles) {
+            newSharees.append(parseSharee(circle.toObject()));
+        }
     }
 
     {
@@ -120,6 +129,12 @@ void ShareeModel::shareesFetched(const QJsonDocument &reply)
             newSharees.append(parseSharee(remote.toObject()));
         }
     }
+    {
+        auto circles = data.value("circles").toArray();
+        foreach (auto circle, circles) {
+            newSharees.append(parseSharee(circle.toObject()));
+        }
+    }
 
     // Filter sharees that we have already shared with
     QVector<QSharedPointer<Sharee>> filteredSharees;
