@@ -12,7 +12,7 @@
 
 namespace OCC {
 
-Q_LOGGING_CATEGORY(lcWizardWebiewPage, "gui.wizard.webviewpage", QtInfoMsg)
+Q_LOGGING_CATEGORY(lcWizardWebiewPage, "nextcloud.gui.wizard.webviewpage", QtInfoMsg)
 
 
 WebViewPage::WebViewPage(QWidget *parent)
@@ -23,7 +23,7 @@ WebViewPage::WebViewPage(QWidget *parent)
     qCInfo(lcWizardWebiewPage()) << "Time for a webview!";
     _webView = new WebView(this);
 
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
     layout->addWidget(_webView);
     setLayout(layout);
 
