@@ -293,7 +293,7 @@ protected:
 	bool finished() override;
 
 signals:
-	void encryptStatusReceived(const QMap<QString, bool> folderMetadata2EncryptionStatus);
+    void encryptStatusReceived(const QHash<QString, bool> folderMetadata2EncryptionStatus);
     void encryptStatusFolderReceived(const QString &folder, bool isEncrypted);
 	void encryptStatusError(int statusCode);
 private:
