@@ -18,7 +18,6 @@
 #include <QHash>
 #include <QObject>
 #include <QMap>
-#include <QLinkedList>
 #include <QElapsedTimer>
 #include <QTimer>
 #include <QPointer>
@@ -384,7 +383,11 @@ public:
 
     ~OwncloudPropagator();
 
-    void start(const SyncFileItemVector &_syncedItems);
+    void start(const SyncFileItemVector &_syncedItems,
+               const bool &hasChange = false,
+               const int &lastChangeInstruction = 0,
+               const bool &hasDelete = false,
+               const int &lastDeleteInstruction = 0);
 
     const SyncOptions &syncOptions() const;
     void setSyncOptions(const SyncOptions &syncOptions);
