@@ -16,15 +16,34 @@ namespace OCC {
 
 Q_LOGGING_CATEGORY(lcPropagateUploadEncrypted, "nextcloud.sync.propagator.upload.encrypted", QtInfoMsg)
 
-PropagateUploadEncrypted::PropagateUploadEncrypted(OwncloudPropagator *propagator, SyncFileItemPtr item)
-: _propagator(propagator),
- _item(item),
- _metadata(nullptr)
+PropagateUploadEncrypted::PropagateUploadEncrypted(OwncloudPropagator *propagator, const QString &remoteParentPath, SyncFileItemPtr item, QObject *parent)
+    : QObject(parent)
+    , _propagator(propagator)
+    , _remoteParentPath(remoteParentPath)
+    , _item(item)
+    , _metadata(nullptr)
 {
 }
 
 void PropagateUploadEncrypted::start()
 {
+    const auto rootPath = [=]() {
+        const auto result = _propagator->_remoteFolder;
+        if (result.startsWith('/')) {
+            return result.mid(1);
+        } else {
+            return result;
+        }
+    }();
+    const auto absoluteRemoteParentPath = [=]{
+        auto path = QString(rootPath + _remoteParentPath);
+        if (path.endsWith('/')) {
+            path.chop(1);
+        }
+        return path;
+    }();
+
+
   /* If the file is in a encrypted-enabled nextcloud instance, we need to
       * do the long road: Fetch the folder status of the encrypted bit,
       * if it's encrypted, find the ID of the folder.
@@ -38,9 +57,7 @@ void PropagateUploadEncrypted::start()
       * If the folder is unencrypted we just follow the old way.
       */
       qCDebug(lcPropagateUploadEncrypted) << "Starting to send an encrypted file!";
-      QFileInfo info(_item->_file);
-      auto getEncryptedStatus = new GetFolderEncryptStatusJob(_propagator->account(),
-                                                           info.path());
+      auto getEncryptedStatus = new GetFolderEncryptStatusJob(_propagator->account(), absoluteRemoteParentPath, this);
 
       connect(getEncryptedStatus, &GetFolderEncryptStatusJob::encryptStatusFolderReceived,
               this, &PropagateUploadEncrypted::slotFolderEncryptedStatusFetched);
@@ -63,7 +80,7 @@ void PropagateUploadEncrypted::slotFolderEncryptedStatusFetched(const QString &f
       job->start();
   } else {
     qCDebug(lcPropagateUploadEncrypted) << "Folder is not encrypted, getting back to default.";
-    emit folerNotEncrypted();
+    emit folderNotEncrypted();
   }
 }
 
@@ -116,8 +133,11 @@ void PropagateUploadEncrypted::slotFolderEncryptedMetadataError(const QByteArray
 {
     Q_UNUSED(fileId);
     Q_UNUSED(httpReturnCode);
-    qCDebug(lcPropagateUploadEncrypted()) << "Error Getting the encrypted metadata. unlock the folder.";
-    unlockFolder();
+    qCDebug(lcPropagateUploadEncrypted()) << "Error Getting the encrypted metadata. Pretend we got empty metadata.";
+    FolderMetadata emptyMetadata(_propagator->account());
+    emptyMetadata.encryptedMetadata();
+    auto json = QJsonDocument::fromJson(emptyMetadata.encryptedMetadata());
+    slotFolderEncryptedMetadataReceived(json, httpReturnCode);
 }
 
 void PropagateUploadEncrypted::slotFolderEncryptedMetadataReceived(const QJsonDocument &json, int statusCode)
@@ -157,32 +177,34 @@ void PropagateUploadEncrypted::slotFolderEncryptedMetadataReceived(const QJsonDo
       encryptedFile.mimetype = mdb.mimeTypeForFile(info).name().toLocal8Bit();
   }
 
-  _item->_encryptedFileName = _item->_file.section(QLatin1Char('/'), 0, -2)
-          + QLatin1Char('/') + encryptedFile.encryptedFilename;
+  _item->_encryptedFileName = _remoteParentPath + QLatin1Char('/') + encryptedFile.encryptedFilename;
 
   qCDebug(lcPropagateUploadEncrypted) << "Creating the encrypted file.";
 
-  QFile input(info.absoluteFilePath());
-  QFile output(QDir::tempPath() + QDir::separator() + encryptedFile.encryptedFilename);
+  if (info.isDir()) {
+      _completeFileName = encryptedFile.encryptedFilename;
+  } else {
+      QFile input(info.absoluteFilePath());
+      QFile output(QDir::tempPath() + QDir::separator() + encryptedFile.encryptedFilename);
 
-  QByteArray tag;
-  bool encryptionResult = EncryptionHelper::fileEncryption(
-    encryptedFile.encryptionKey,
-    encryptedFile.initializationVector,
-    &input, &output, tag);
+      QByteArray tag;
+      bool encryptionResult = EncryptionHelper::fileEncryption(
+        encryptedFile.encryptionKey,
+        encryptedFile.initializationVector,
+        &input, &output, tag);
 
-  if (!encryptionResult) {
-    qCDebug(lcPropagateUploadEncrypted()) << "There was an error encrypting the file, aborting upload.";
-    unlockFolder();
-    return;
+      if (!encryptionResult) {
+        qCDebug(lcPropagateUploadEncrypted()) << "There was an error encrypting the file, aborting upload.";
+        unlockFolder();
+        return;
+      }
+
+      encryptedFile.authenticationTag = tag;
+      _completeFileName = output.fileName();
   }
 
-  _completeFileName = output.fileName();
-
   qCDebug(lcPropagateUploadEncrypted) << "Creating the metadata for the encrypted file.";
 
-  encryptedFile.authenticationTag = tag;
-
   _metadata->addEncryptedFile(encryptedFile);
   _encryptedFile = encryptedFile;
 
@@ -216,7 +238,7 @@ void PropagateUploadEncrypted::slotUpdateMetadataSuccess(const QByteArray& fileI
     qCDebug(lcPropagateUploadEncrypted) << "Encrypted Info:" << outputInfo.path() << outputInfo.fileName() << outputInfo.size();
     qCDebug(lcPropagateUploadEncrypted) << "Finalizing the upload part, now the actuall uploader will take over";
     emit finalized(outputInfo.path() + QLatin1Char('/') + outputInfo.fileName(),
-                   _item->_file.section(QLatin1Char('/'), 0, -2) + QLatin1Char('/') + outputInfo.fileName(),
+                   _remoteParentPath + QLatin1Char('/') + outputInfo.fileName(),
                    outputInfo.size());
 }
 
@@ -242,7 +264,7 @@ void PropagateUploadEncrypted::slotFolderLockedError(const QByteArray& fileId, i
 
         // Perhaps I should remove the elapsed timer if the lock is from this client?
         if (_folderLockFirstTry.elapsed() > /* five minutes */ 1000 * 60 * 5 ) {
-            qCDebug(lcPropagateUploadEncrypted) << "One minute passed, ignoring more attemps to lock the folder.";
+            qCDebug(lcPropagateUploadEncrypted) << "One minute passed, ignoring more attempts to lock the folder.";
         return;
         }
         slotTryLock(fileId);
