@@ -139,7 +139,7 @@ void PropagateUploadFileV1::startNextChunk()
 
     // job takes ownership of device via a QScopedPointer. Job deletes itself when finishing
     auto devicePtr = device.get(); // for connections later
-    PUTFileJob *job = new PUTFileJob(propagator()->account(), propagator()->_remoteFolder + path, std::move(device), headers, _currentChunk, this);
+    auto *job = new PUTFileJob(propagator()->account(), propagator()->_remoteFolder + path, std::move(device), headers, _currentChunk, this);
     _jobs.append(job);
     connect(job, &PUTFileJob::finishedSignal, this, &PropagateUploadFileV1::slotPutFinished);
     connect(job, &PUTFileJob::uploadProgress, this, &PropagateUploadFileV1::slotUploadProgress);
@@ -187,7 +187,7 @@ void PropagateUploadFileV1::startNextChunk()
 
 void PropagateUploadFileV1::slotPutFinished()
 {
-    PUTFileJob *job = qobject_cast<PUTFileJob *>(sender());
+    auto *job = qobject_cast<PUTFileJob *>(sender());
     ASSERT(job);
 
     slotJobDestroyed(job); // remove it from the _jobs list
@@ -357,7 +357,7 @@ void PropagateUploadFileV1::abort(PropagatorJob::AbortType abortType)
     abortNetworkJobs(
         abortType,
         [this, abortType](AbstractNetworkJob *job) {
-            if (PUTFileJob *putJob = qobject_cast<PUTFileJob *>(job)){
+            if (auto *putJob = qobject_cast<PUTFileJob *>(job)){
                 if (abortType == AbortType::Asynchronous
                     && _chunkCount > 0
                     && (((_currentChunk + _startChunk) % _chunkCount) == 0)
