@@ -326,12 +326,17 @@ void SyncEngine::deleteStaleErrorBlacklistEntries(const SyncFileItemVector &sync
     _journal->deleteStaleErrorBlacklistEntries(blacklist_file_paths);
 }
 
+#if (QT_VERSION < 0x050600)
+template <typename T>
+constexpr typename std::add_const<T>::type &qAsConst(T &t) noexcept { return t; }
+#endif
+
 void SyncEngine::conflictRecordMaintenance()
 {
     // Remove stale conflict entries from the database
     // by checking which files still exist and removing the
     // missing ones.
-    auto conflictRecordPaths = _journal->conflictRecordPaths();
+    const auto conflictRecordPaths = _journal->conflictRecordPaths();
     for (const auto &path : conflictRecordPaths) {
         auto fsPath = _propagator->getFilePath(QString::fromUtf8(path));
         if (!QFileInfo(fsPath).exists()) {
@@ -344,7 +349,7 @@ void SyncEngine::conflictRecordMaintenance()
     //
     // This happens when the conflicts table is new or when conflict files
     // are downlaoded but the server doesn't send conflict headers.
-    for (const auto &path : _seenFiles) {
+    for (const auto &path : qAsConst(_seenFiles)) {
         if (!Utility::isConflictFile(path))
             continue;
 
@@ -599,7 +604,6 @@ int SyncEngine::treewalkFile(csync_file_stat_t *file, csync_file_stat_t *other,
         dir = SyncFileItem::None;
         // For directories, metadata-only updates will be done after all their files are propagated.
         if (!isDirectory) {
-
             // Update the database now already:  New remote fileid or Etag or RemotePerm
             // Or for files that were detected as "resolved conflict".
             // Or a local inode/mtime change
@@ -761,7 +765,7 @@ void SyncEngine::startSync()
         QVector<SyncJournalDb::PollInfo> pollInfos = _journal->getPollInfos();
         if (!pollInfos.isEmpty()) {
             qCInfo(lcEngine) << "Finish Poll jobs before starting a sync";
-            CleanupPollsJob *job = new CleanupPollsJob(pollInfos, _account,
+            auto *job = new CleanupPollsJob(pollInfos, _account,
                 _journal, _localPath, this);
             connect(job, &CleanupPollsJob::finished, this, &SyncEngine::startSync);
             connect(job, &CleanupPollsJob::aborted, this, &SyncEngine::slotCleanPollsJobAborted);
@@ -854,7 +858,70 @@ void SyncEngine::startSync()
         return shouldDiscoverLocally(path);
     };
 
-    bool ok;
+    // If needed, make sure we have up to date E2E information before the
+    // discovery phase, otherwise we start right away
+    if (_account->capabilities().clientSideEncryptionAvailable()) {
+        connect(_account->e2e(), &ClientSideEncryption::folderEncryptedStatusFetchDone,
+                this, &SyncEngine::onFolderEncryptedStatusFetchDone);
+        _account->e2e()->fetchFolderEncryptedStatus();
+    } else {
+        slotStartDiscovery();
+    }
+}
+
+void SyncEngine::onFolderEncryptedStatusFetchDone(const QHash<QString, bool> &values)
+{
+    disconnect(_account->e2e(), &ClientSideEncryption::folderEncryptedStatusFetchDone,
+               this, &SyncEngine::onFolderEncryptedStatusFetchDone);
+
+    Q_ASSERT(_remotePath.startsWith('/'));
+    const auto rootPath = [=]() {
+        const auto result = _remotePath;
+        if (result.startsWith('/')) {
+            return result.mid(1);
+        } else {
+            return result;
+        }
+    }();
+
+    std::for_each(values.constKeyValueBegin(), values.constKeyValueEnd(), [=](const std::pair<QString, bool> &pair) {
+        const auto key = pair.first;
+        const auto value = pair.second;
+
+        if (!key.startsWith(rootPath)) {
+            return;
+        }
+
+        Q_ASSERT(key.endsWith('/'));
+        const auto path = key.mid(rootPath.length()).chopped(1);
+
+        if (path.isEmpty()) {
+            // We don't store metadata about the root
+            return;
+        }
+
+        SyncJournalFileRecord rec;
+        _journal->getFileRecordByE2eMangledName(path, &rec);
+
+        if (!rec.isValid()) {
+            _journal->getFileRecord(path, &rec);
+        }
+
+        if (!rec.isValid()) {
+            // We don't know that folder yet anyway...
+            return;
+        }
+
+        rec._isE2eEncrypted = value;
+        _journal->setFileRecord(rec);
+    });
+
+    slotStartDiscovery();
+}
+
+void SyncEngine::slotStartDiscovery()
+{
+    bool ok = false;
     auto selectiveSyncBlackList = _journal->getSelectiveSyncList(SyncJournalDb::SelectiveSyncBlackList, &ok);
     if (ok) {
         bool usingSelectiveSync = (!selectiveSyncBlackList.isEmpty());
@@ -895,7 +962,7 @@ void SyncEngine::startSync()
         connect(_discoveryMainThread.data(), &DiscoveryMainThread::etagConcatenation, this, &SyncEngine::slotRootEtagReceived);
     }
 
-    DiscoveryJob *discoveryJob = new DiscoveryJob(_csync_ctx.data());
+    auto *discoveryJob = new DiscoveryJob(_csync_ctx.data());
     discoveryJob->_selectiveSyncBlackList = selectiveSyncBlackList;
     discoveryJob->_selectiveSyncWhiteList =
         _journal->getSelectiveSyncList(SyncJournalDb::SelectiveSyncWhiteList, &ok);
@@ -973,6 +1040,16 @@ void SyncEngine::slotDiscoveryJobFinished(int discoveryResult)
         _journal->commitIfNeededAndStartNewTransaction("Post discovery");
     }
 
+    // FIXME: This is a reasonable safety check, but specifically just a hotfix.
+    // See: https://github.com/nextcloud/desktop/issues/1433
+    // It's still unclear why we can get an empty FileMap even though folder isn't empty
+    // For now: Re-check if folder is really empty, if not bail out
+    if (_csync_ctx.data()->local.files.empty() && QDir(_localPath).entryInfoList(QDir::NoDotAndDotDot).count() > 0) {
+        qCWarning(lcEngine) << "Received local tree with empty FileMap but sync folder isn't empty. Won't reconcile.";
+        finalize(false);
+        return;
+    }
+
     _progressInfo->_currentDiscoveredRemoteFolder.clear();
     _progressInfo->_currentDiscoveredLocalFolder.clear();
     _progressInfo->_status = ProgressInfo::Reconcile;
@@ -994,11 +1071,11 @@ void SyncEngine::slotDiscoveryJobFinished(int discoveryResult)
     _temporarilyUnavailablePaths.clear();
     _renamedFolders.clear();
 
-    if (csync_walk_local_tree(_csync_ctx.data(), [this](csync_file_stat_t *f, csync_file_stat_t *o) { return treewalkFile(f, o, false); } ) < 0) {
+    if (csync_walk_local_tree(_csync_ctx.data(), [this](csync_file_stat_t *f, csync_file_stat_t *o) { return treewalkFile(f, o, false); }) < 0) {
         qCWarning(lcEngine) << "Error in local treewalk.";
         walkOk = false;
     }
-    if (walkOk && csync_walk_remote_tree(_csync_ctx.data(), [this](csync_file_stat_t *f, csync_file_stat_t *o) { return treewalkFile(f, o, true); } ) < 0) {
+    if (walkOk && csync_walk_remote_tree(_csync_ctx.data(), [this](csync_file_stat_t *f, csync_file_stat_t *o) { return treewalkFile(f, o, true); }) < 0) {
         qCWarning(lcEngine) << "Error in remote treewalk.";
     }
 
@@ -1023,7 +1100,7 @@ void SyncEngine::slotDiscoveryJobFinished(int discoveryResult)
         // files with names that contain these.
         // It's important to respect the capability also for older servers -- the
         // version check doesn't make sense for custom servers.
-        invalidFilenamePattern = "[\\\\:?*\"<>|]";
+        invalidFilenamePattern = R"([\\:?*"<>|])";
     }
     if (!invalidFilenamePattern.isEmpty()) {
         const QRegExp invalidFilenameRx(invalidFilenamePattern);
@@ -1070,8 +1147,53 @@ void SyncEngine::slotDiscoveryJobFinished(int discoveryResult)
         }
     }
 
-    // Sort items per destination
-    std::sort(syncItems.begin(), syncItems.end());
+    bool hasChange = false;
+    bool hasDelete = false;
+    int lastChangeInstruction = 0;
+    int lastDeleteInstruction = 0;
+
+    // Only if list is populated, can be empty under certain circumstances
+    // Get CHANGE instructions to the top first
+    if (syncItems.count() > 0) {
+        std::sort(syncItems.begin(), syncItems.end(),
+            [](SyncFileItemVector::const_reference &a, SyncFileItemVector::const_reference &b) -> bool {
+				return ((a->_instruction == CSYNC_INSTRUCTION_TYPE_CHANGE) && (b->_instruction != CSYNC_INSTRUCTION_TYPE_CHANGE));
+            });
+        if (syncItems.at(0)->_instruction == CSYNC_INSTRUCTION_TYPE_CHANGE) {
+            hasChange = true;
+            lastChangeInstruction = std::distance(syncItems.begin(), std::find_if(syncItems.begin(), syncItems.end(), [](SyncFileItemVector::const_reference &a) -> bool { return a->_instruction != CSYNC_INSTRUCTION_TYPE_CHANGE; }));
+        }
+        if (hasChange) {
+            std::sort(syncItems.begin(), syncItems.begin() + lastChangeInstruction);
+            if (syncItems.count() > lastChangeInstruction) {
+                std::sort(syncItems.begin() + (lastChangeInstruction + 1), syncItems.end(),
+                    [](SyncFileItemVector::const_reference &a, SyncFileItemVector::const_reference &b) -> bool {
+                        return ((a->_instruction == CSYNC_INSTRUCTION_REMOVE) && (b->_instruction != CSYNC_INSTRUCTION_REMOVE));
+                    });
+                if (syncItems.at(lastChangeInstruction + 1)->_instruction == CSYNC_INSTRUCTION_REMOVE) {
+                    hasDelete = true;
+                    lastDeleteInstruction = std::distance(syncItems.begin(), std::find_if(syncItems.begin() + (lastChangeInstruction + 1), syncItems.end(), [](SyncFileItemVector::const_reference &a) -> bool { return a->_instruction != CSYNC_INSTRUCTION_REMOVE; }));
+                    std::sort(syncItems.begin() + (lastChangeInstruction + 1), syncItems.begin() + lastDeleteInstruction);
+                    if (syncItems.count() > lastDeleteInstruction) {
+                        std::sort(syncItems.begin() + (lastDeleteInstruction + 1), syncItems.end());
+                    }
+                } else {
+                    std::sort(syncItems.begin() + (lastChangeInstruction + 1), syncItems.end());
+                }
+            }
+        } else if (syncItems.at(0)->_instruction == CSYNC_INSTRUCTION_REMOVE) {
+            hasDelete = true;
+            lastDeleteInstruction = std::distance(syncItems.begin(), std::find_if(syncItems.begin(), syncItems.end(), [](SyncFileItemVector::const_reference &a) -> bool { return a->_instruction != CSYNC_INSTRUCTION_REMOVE; }));
+            std::sort(syncItems.begin(), syncItems.begin() + lastDeleteInstruction);
+			if (syncItems.count() > lastDeleteInstruction) {
+                std::sort(syncItems.begin() + (lastDeleteInstruction + 1), syncItems.end());
+            }
+        } else {
+            std::sort(syncItems.begin(), syncItems.end());
+        }
+    }
+
+    //std::sort(syncItems.begin(), syncItems.end());
 
     // make sure everything is allowed
     checkForPermission(syncItems);
@@ -1129,7 +1251,7 @@ void SyncEngine::slotDiscoveryJobFinished(int discoveryResult)
     if (_needsUpdate)
         emit(started());
 
-    _propagator->start(syncItems);
+    _propagator->start(syncItems, hasChange, lastChangeInstruction, hasDelete, lastDeleteInstruction);
 
     qCInfo(lcEngine) << "#### Post-Reconcile end #################################################### " << _stopWatch.addLapTime(QLatin1String("Post-Reconcile Finished")) << "ms";
 }
@@ -1253,7 +1375,7 @@ QString SyncEngine::adjustRenamedPath(const QString &original)
  */
 void SyncEngine::checkForPermission(SyncFileItemVector &syncItems)
 {
-    bool selectiveListOk;
+    bool selectiveListOk = false;
     auto selectiveSyncBlackList = _journal->getSelectiveSyncList(SyncJournalDb::SelectiveSyncBlackList, &selectiveListOk);
     std::sort(selectiveSyncBlackList.begin(), selectiveSyncBlackList.end());
     SyncFileItemPtr needle;
@@ -1269,8 +1391,7 @@ void SyncEngine::checkForPermission(SyncFileItemVector &syncItems)
         const QString path = (*it)->destination() + QLatin1Char('/');
 
         // if reading the selective sync list from db failed, lets ignore all rather than nothing.
-        if (!selectiveListOk || std::binary_search(selectiveSyncBlackList.constBegin(), selectiveSyncBlackList.constEnd(),
-                                    path)) {
+        if (!selectiveListOk || std::binary_search(selectiveSyncBlackList.constBegin(), selectiveSyncBlackList.constEnd(), path)) {
             (*it)->_instruction = CSYNC_INSTRUCTION_IGNORE;
             (*it)->_status = SyncFileItem::FileIgnored;
             (*it)->_errorString = tr("Ignored because of the \"choose what to sync\" blacklist");
@@ -1465,7 +1586,7 @@ void SyncEngine::checkForPermission(SyncFileItemVector &syncItems)
             bool sourceOK = true;
             if (!filePerms.isNull()
                 && ((isRename && !filePerms.hasPermission(RemotePermissions::CanRename))
-                       || (!isRename && !filePerms.hasPermission(RemotePermissions::CanMove)))) {
+                    || (!isRename && !filePerms.hasPermission(RemotePermissions::CanMove)))) {
                 // We are not allowed to move or rename this file
                 sourceOK = false;
 
@@ -1545,7 +1666,7 @@ RemotePermissions SyncEngine::getPermissions(const QString &file) const
     if (it != _csync_ctx->remote.files.end()) {
         return it->second->remotePerm;
     }
-    return RemotePermissions();
+    return {};
 }
 
 void SyncEngine::restoreOldFiles(SyncFileItemVector &syncItems)
@@ -1616,8 +1737,8 @@ bool SyncEngine::wasFileTouched(const QString &fn) const
     // Start from the end (most recent) and look for our path. Check the time just in case.
     auto begin = _touchedFiles.constBegin();
     for (auto it = _touchedFiles.constEnd(); it != begin; --it) {
-        if ((it-1).value() == fn)
-            return (it-1).key().elapsed() <= s_touchedFilesMaxAgeMs;
+        if ((it - 1).value() == fn)
+            return (it - 1).key().elapsed() <= s_touchedFilesMaxAgeMs;
     }
     return false;
 }
