@@ -139,7 +139,7 @@ SyncFileStatus SyncFileStatusTracker::fileStatus(const QString &relativePath)
     if (_syncEngine->excludedFiles().isExcluded(_syncEngine->localPath() + relativePath,
             _syncEngine->localPath(),
             _syncEngine->ignoreHiddenFiles())) {
-        return SyncFileStatus(SyncFileStatus::StatusWarning);
+        return SyncFileStatus::StatusWarning;
     }
 
     if (_dirtyPaths.contains(relativePath))
@@ -290,8 +290,14 @@ void SyncFileStatusTracker::slotSyncFinished()
     // Clear the sync counts to reduce the impact of unsymetrical inc/dec calls (e.g. when directory job abort)
     QHash<QString, int> oldSyncCount;
     std::swap(_syncCount, oldSyncCount);
-    for (auto it = oldSyncCount.begin(); it != oldSyncCount.end(); ++it)
+    for (auto it = oldSyncCount.begin(); it != oldSyncCount.end(); ++it) {
+        // Don't announce folders, fileStatus expect only paths without '/', otherwise it asserts
+        if (it.key().endsWith('/')) {
+            continue;
+        }
+
         emit fileStatusChanged(getSystemDestination(it.key()), fileStatus(it.key()));
+    }
 }
 
 void SyncFileStatusTracker::slotSyncEngineRunningChanged()
