@@ -24,6 +24,7 @@
 #include <QApplication>
 #endif
 #include <QSslSocket>
+#include <QSvgRenderer>
 
 #include "nextcloudtheme.h"
 
@@ -49,9 +50,7 @@ Theme *Theme::instance()
     return _instance;
 }
 
-Theme::~Theme()
-{
-}
+Theme::~Theme() = default;
 
 QString Theme::statusHeaderText(SyncResult::Status status) const
 {
@@ -92,6 +91,11 @@ QString Theme::statusHeaderText(SyncResult::Status status) const
     return resultStr;
 }
 
+bool Theme::isBranded() const
+{
+    return appNameGUI() != QStringLiteral("Nextcloud");
+}
+
 QString Theme::appNameGUI() const
 {
     return APPLICATION_NAME;
@@ -123,11 +127,11 @@ QIcon Theme::applicationIcon() const
  * helper to load a icon from either the icon theme the desktop provides or from
  * the apps Qt resources.
  */
-QIcon Theme::themeIcon(const QString &name, bool sysTray, bool sysTrayMenuVisible) const
+QIcon Theme::themeIcon(const QString &name, bool sysTray) const
 {
     QString flavor;
     if (sysTray) {
-        flavor = systrayIconFlavor(_mono, sysTrayMenuVisible);
+        flavor = systrayIconFlavor(_mono);
     } else {
         flavor = QLatin1String("colored");
     }
@@ -140,29 +144,36 @@ QIcon Theme::themeIcon(const QString &name, bool sysTray, bool sysTrayMenuVisibl
             return cached = QIcon::fromTheme(name);
         }
 
-        QList<int> sizes;
-        sizes << 16 << 22 << 32 << 48 << 64 << 128 << 256 << 512 << 1024;
-        foreach (int size, sizes) {
-            QString pixmapName = QString::fromLatin1(":/client/theme/%1/%2-%3.png").arg(flavor).arg(name).arg(size);
-            if (QFile::exists(pixmapName)) {
-                QPixmap px(pixmapName);
-                // HACK, get rid of it by supporting FDO icon themes, this is really just emulating ubuntu-mono
-                if (qgetenv("DESKTOP_SESSION") == "ubuntu") {
-                    QBitmap mask = px.createMaskFromColor(Qt::white, Qt::MaskOutColor);
-                    QPainter p(&px);
-                    p.setPen(QColor("#dfdbd2"));
-                    p.drawPixmap(px.rect(), mask, mask.rect());
-                }
-                cached.addPixmap(px);
+        const auto svgName = QString::fromLatin1(":/client/theme/%1/%2.svg").arg(flavor).arg(name);
+        QSvgRenderer renderer(svgName);
+        const auto createPixmapFromSvg = [&renderer] (int size) {
+            QImage img(size, size, QImage::Format_ARGB32);
+            img.fill(Qt::GlobalColor::transparent);
+            QPainter imgPainter(&img);
+            renderer.render(&imgPainter);
+            return QPixmap::fromImage(img);
+        };
+
+        const auto loadPixmap = [flavor, name] (int size) {
+            const auto pixmapName = QString::fromLatin1(":/client/theme/%1/%2-%3.png").arg(flavor).arg(name).arg(size);
+            return QPixmap(pixmapName);
+        };
+
+        const auto sizes = isBranded() ? QVector<int>{ 16, 22, 32, 48, 64, 128, 256, 512, 1024 }
+                                       : QVector<int>{ 16, 32, 64, 128, 256 };
+        for (int size : sizes) {
+            auto px = isBranded() ? loadPixmap(size) : createPixmapFromSvg(size);
+            if (px.isNull()) {
+                continue;
             }
-        }
-        if (cached.isNull()) {
-            foreach (int size, sizes) {
-                QString pixmapName = QString::fromLatin1(":/client/resources/%1-%2.png").arg(name).arg(size);
-                if (QFile::exists(pixmapName)) {
-                    cached.addFile(pixmapName);
-                }
+            // HACK, get rid of it by supporting FDO icon themes, this is really just emulating ubuntu-mono
+            if (qgetenv("DESKTOP_SESSION") == "ubuntu") {
+                QBitmap mask = px.createMaskFromColor(Qt::white, Qt::MaskOutColor);
+                QPainter p(&px);
+                p.setPen(QColor("#dfdbd2"));
+                p.drawPixmap(px.rect(), mask, mask.rect());
             }
+            cached.addPixmap(px);
         }
     }
 
@@ -170,7 +181,7 @@ QIcon Theme::themeIcon(const QString &name, bool sysTray, bool sysTrayMenuVisibl
 #if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
     // This defines the icon as a template and enables automatic macOS color handling
     // See https://bugreports.qt.io/browse/QTBUG-42109
-    cached.setIsMask(_mono && sysTray && !sysTrayMenuVisible);
+    cached.setIsMask(_mono && sysTray);
 #endif
 #endif
 
@@ -210,7 +221,6 @@ QString Theme::hidpiFileName(const QString &fileName, QPaintDevice *dev)
 
 Theme::Theme()
     : QObject(nullptr)
-    , _mono(false)
 {
 }
 
@@ -270,18 +280,11 @@ QString Theme::defaultClientFolder() const
     return appName();
 }
 
-QString Theme::systrayIconFlavor(bool mono, bool sysTrayMenuVisible) const
+QString Theme::systrayIconFlavor(bool mono) const
 {
-    Q_UNUSED(sysTrayMenuVisible)
     QString flavor;
     if (mono) {
         flavor = Utility::hasDarkSystray() ? QLatin1String("white") : QLatin1String("black");
-
-#ifdef Q_OS_MAC
-        if (sysTrayMenuVisible) {
-            flavor = QLatin1String("white");
-        }
-#endif
     } else {
         flavor = QLatin1String("colored");
     }
@@ -347,6 +350,24 @@ QString Theme::gitSHA1() const
 }
 
 QString Theme::about() const
+{
+    // Shorten Qt's OS name: "macOS Mojave (10.14)" -> "macOS"
+    QStringList osStringList = Utility::platformName().split(QLatin1Char(' '));
+    QString osName = osStringList.at(0);
+
+    QString devString;
+    //: Example text: "<p>Nextcloud Desktop Client</p>"   (%1 is the application name)
+    devString = tr("<p>%1 Desktop Client</p>")
+              .arg(APPLICATION_NAME);
+
+    devString += tr("<p>Version %1. For more information please click <a href='%2'>here</a>.</p>")
+              .arg(QString::fromLatin1(MIRALL_STRINGIFY(MIRALL_VERSION)) + QString(" (%1)").arg(osName))
+              .arg(helpUrl());
+
+    return devString;
+}
+
+QString Theme::aboutDetails() const
 {
     QString devString;
     devString = tr("<p>Version %1. For more information please click <a href='%2'>here</a>.</p>")
@@ -395,7 +416,7 @@ QVariant Theme::customMedia(CustomMediaType type)
     return re;
 }
 
-QIcon Theme::syncStateIcon(SyncResult::Status status, bool sysTray, bool sysTrayMenuVisible) const
+QIcon Theme::syncStateIcon(SyncResult::Status status, bool sysTray) const
 {
     // FIXME: Mind the size!
     QString statusIcon;
@@ -427,7 +448,7 @@ QIcon Theme::syncStateIcon(SyncResult::Status status, bool sysTray, bool sysTray
         statusIcon = QLatin1String("state-error");
     }
 
-    return themeIcon(statusIcon, sysTray, sysTrayMenuVisible);
+    return themeIcon(statusIcon, sysTray);
 }
 
 QIcon Theme::folderDisabledIcon() const
@@ -435,19 +456,19 @@ QIcon Theme::folderDisabledIcon() const
     return themeIcon(QLatin1String("state-pause"));
 }
 
-QIcon Theme::folderOfflineIcon(bool sysTray, bool sysTrayMenuVisible) const
+QIcon Theme::folderOfflineIcon(bool sysTray) const
 {
-    return themeIcon(QLatin1String("state-offline"), sysTray, sysTrayMenuVisible);
+    return themeIcon(QLatin1String("state-offline"), sysTray);
 }
 
 QColor Theme::wizardHeaderTitleColor() const
 {
-    return QColor(APPLICATION_WIZARD_HEADER_TITLE_COLOR);
+    return {APPLICATION_WIZARD_HEADER_TITLE_COLOR};
 }
 
 QColor Theme::wizardHeaderBackgroundColor() const
 {
-    return QColor(APPLICATION_WIZARD_HEADER_BACKGROUND_COLOR);
+    return {APPLICATION_WIZARD_HEADER_BACKGROUND_COLOR};
 }
 
 QPixmap Theme::wizardHeaderLogo() const
@@ -561,7 +582,12 @@ QString Theme::versionSwitchOutput() const
     stream << "Git revision " << GIT_SHA1 << endl;
 #endif
     stream << "Using Qt " << qVersion() << ", built against Qt " << QT_VERSION_STR << endl;
+
+    if(!QGuiApplication::platformName().isEmpty())
+        stream << "Using Qt platform plugin '" << QGuiApplication::platformName() << "'" << endl;
+
     stream << "Using '" << QSslSocket::sslLibraryVersionString() << "'" << endl;
+    stream << "Running on " << Utility::platformName() << ", " << QSysInfo::currentCpuArchitecture() << endl;
     return helpText;
 }
 
@@ -574,7 +600,7 @@ bool Theme::isDarkColor(const QColor &color)
 
 QColor Theme::getBackgroundAwareLinkColor(const QColor &backgroundColor)
 {
-    return QColor((isDarkColor(backgroundColor) ? QColor("#6193dc") : QGuiApplication::palette().color(QPalette::Link)));
+    return {(isDarkColor(backgroundColor) ? QColor("#6193dc") : QGuiApplication::palette().color(QPalette::Link))};
 }
 
 QColor Theme::getBackgroundAwareLinkColor()
@@ -599,8 +625,17 @@ void Theme::replaceLinkColorString(QString &linkString, const QColor &newColor)
 
 QIcon Theme::createColorAwareIcon(const QString &name, const QPalette &palette)
 {
-    QImage img(name);
-    QImage inverted(img);
+    QSvgRenderer renderer(name);
+    QImage img(64, 64, QImage::Format_ARGB32);
+    img.fill(Qt::GlobalColor::transparent);
+    QPainter imgPainter(&img);
+    QImage inverted(64, 64, QImage::Format_ARGB32);
+    inverted.fill(Qt::GlobalColor::transparent);
+    QPainter invPainter(&inverted);
+
+    renderer.render(&imgPainter);
+    renderer.render(&invPainter);
+
     inverted.invertPixels(QImage::InvertRgb);
 
     QIcon icon;
